package
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: Feb 24, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Langs []Lang `yaml:"langs"`
Layers []Layer `yaml:"layers"`
}
Config holds the CV configuration.
Load reads and validates a YAML config file.
type Lang struct {
Code string `yaml:"code"`
Label string `yaml:"label"`
}
Lang defines an available language.
Layer defines a key-driven command.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.